package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.EBrand;
import com.ruoyi.system.service.IEBrandService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 品牌商Controller
 *
 * @author 邱贞招
 * @date 2024-07-31
 */
@RestController
@RequestMapping("/system/brand")
public class EBrandController extends BaseController
{
    @Autowired
    private IEBrandService eBrandService;

    /**
     * 查询品牌商列表
     */
    @PreAuthorize("@ss.hasPermi('system:brand:list')")
    @GetMapping("/list")
    public TableDataInfo list(EBrand eBrand)
    {
        startPage();
        List<EBrand> list = eBrandService.selectEBrandList(eBrand);
        return getDataTable(list);
    }

    /**
     * 导出品牌商列表
     */
    @PreAuthorize("@ss.hasPermi('system:brand:export')")
    @Log(title = "品牌商", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EBrand eBrand)
    {
        List<EBrand> list = eBrandService.selectEBrandList(eBrand);
        ExcelUtil<EBrand> util = new ExcelUtil<EBrand>(EBrand.class);
        util.exportExcel(response, list, "品牌商数据");
    }

    /**
     * 获取品牌商详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:brand:query')")
    @GetMapping(value = "/{brandId}")
    public AjaxResult getInfo(@PathVariable("brandId") Long brandId)
    {
        return success(eBrandService.selectEBrandByBrandId(brandId));
    }

    /**
     * 新增品牌商
     */
    @PreAuthorize("@ss.hasPermi('system:brand:add')")
    @Log(title = "品牌商", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EBrand eBrand)
    {
        return toAjax(eBrandService.insertEBrand(eBrand));
    }

    /**
     * 修改品牌商
     */
    @PreAuthorize("@ss.hasPermi('system:brand:edit')")
    @Log(title = "品牌商", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EBrand eBrand)
    {
        return toAjax(eBrandService.updateEBrand(eBrand));
    }

    /**
     * 删除品牌商
     */
    @PreAuthorize("@ss.hasPermi('system:brand:remove')")
    @Log(title = "品牌商", businessType = BusinessType.DELETE)
	@DeleteMapping("/{brandIds}")
    public AjaxResult remove(@PathVariable Long[] brandIds)
    {
        return toAjax(eBrandService.deleteEBrandByBrandIds(brandIds));
    }
}
