package com.ruoyi.system.service.impl;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.system.domain.rule.EFeeRule;
import com.ruoyi.system.mapper.EFeeRuleMapper;
import com.ruoyi.system.service.IEFeeRuleService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 收费模板Service业务层处理
 *
 * @author qzz
 * @date 2024-09-19
 */
@Service
public class EFeeRuleServiceImpl implements IEFeeRuleService
{
    @Resource
    private EFeeRuleMapper rlFeeRuleMapper;

    /**
     * 查询收费模板
     *
     * @param ruleId 收费模板主键
     * @return 收费模板
     */
    @Override
    public EFeeRule selectRlFeeRuleByRuleId(Long ruleId)
    {
        return rlFeeRuleMapper.selectRlFeeRuleByRuleId(ruleId);
    }

    /**
     * 查询收费模板列表
     *
     * @param rlFeeRule 收费模板
     * @return 收费模板
     */
    @Override
    @DataScope(merchantAlias = "m")
    public List<EFeeRule> selectRlFeeRuleList(EFeeRule rlFeeRule)
    {
        return rlFeeRuleMapper.selectRlFeeRuleList(rlFeeRule);
    }

    /**
     * 查询收费模板列表
     *
     * @param modelId 车型id
     * @return 收费模板
     */
    @Override
    public List<EFeeRule> selectRlFeeRuleListByModelId(Long modelId)
    {
        return rlFeeRuleMapper.selectRlFeeRuleListByModelId(modelId);
    }

    /**
     * 查询收费模板列表ids
     *
     * @param modelId 车型id
     * @return 收费模板集合
     */
    @Override
    public List<Long> selectRlFeeRuleLongListByModelId(Long modelId) {
        return rlFeeRuleMapper.selectRlFeeRuleLongListByModelId(modelId);
    }


    /**
     * 新增收费模板
     *
     * @param rlFeeRule 收费模板
     * @return 结果
     */
    @Override
    public int insertRlFeeRule(EFeeRule rlFeeRule)
    {
        return rlFeeRuleMapper.insertRlFeeRule(rlFeeRule);
    }

    /**
     * 修改收费模板
     *
     * @param rlFeeRule 收费模板
     * @return 结果
     */
    @Override
    public int updateRlFeeRule(EFeeRule rlFeeRule)
    {
        return rlFeeRuleMapper.updateRlFeeRule(rlFeeRule);
    }

    /**
     * 批量删除收费模板
     *
     * @param ruleIds 需要删除的收费模板主键
     * @return 结果
     */
    @Override
    public int deleteRlFeeRuleByRuleIds(Long[] ruleIds)
    {
        return rlFeeRuleMapper.deleteRlFeeRuleByRuleIds(ruleIds);
    }

    /**
     * 删除收费模板信息
     *
     * @param ruleId 收费模板主键
     * @return 结果
     */
    @Override
    public int deleteRlFeeRuleByRuleId(Long ruleId)
    {
        return rlFeeRuleMapper.deleteRlFeeRuleByRuleId(ruleId);
    }
}
